---
title: Brain Function As a Process
id: 155
categories:
  - Research In Brain Function
date: 2007-06-21 13:08:34
tags:
---

Psychological research in general seems to have drifted from it's roots. Thirty years ago, when I was in training, there was a plethora of theoretical articles and books that discussed at length theoretical frameworks for constructs that serves as the building blocks of theory. Concepts in psychological measurement were verified in a process called "construct validity". [Construct validity](http://allpsych.com/stats/unit2/34.html "Statistics Primer: Construct Validity") refers to ability of a concept to explain what is known about the phenomena. Construct validity can seldom be proven because in order for a concept to be meaningful, it must generalize to many similar circumstances. The more meaningful a concept is, the more difficult it becomes to measure. So construct validity can only be supported by repeated measurement from different perspectives.
[Word Net](http://wordnet.princeton.edu/perl/webwn) defines "theory" as a:
> "a well-substantiated explanation of some aspect of the natural world; an organized system of accepted knowledge that applies in a variety of circumstances to explain a specific set of phenomena; "theories can incorporate facts and laws and tested hypotheses"; "true in fact and theory""
A theory connects several constructs into a cohesive whole. A hypothesis is a:
> "tentative theory about the natural world; a concept that is not yet verified but that if true would explain certain facts or phenomena; "a scientific hypothesis that survives experimental testing becomes a scientific theory""
Theoreticians deduce hypothesis from accepted theoretical frameworks and suggest how such hypotheses might be verified by research.  Deductive reasoning involving inferences from general theoretical principles has been considered the preferred way to build hypotheses to be tested. Attempting to generalize to theoretical principles from research results (inductive reasoning) has limited value in that there are often numerous possible explanations for each research result. In other words one needs a theoretical framework to make sense out of individual research results.
Unfortunately, there seems to be little integration of theory and research. While the research I've been reading includes a literature review of similar research, there is less discussion of relevant theories. Discussions include speculation about theory, but the concepts suggested are less likely to apply to a broad theory, and so meaningfulness is limited. Some would call this "dust bowl empiricism."
The following research presents a good example of research that lacks a firm footing in theory.

<!--more-->
[Monitor on Psychology](http://www.apa.org/monitor/oct06/talking.html "Monitor on Psychology - Talking the pain away")
> "In a study published in Science (Vol. 302, No. 5643, pages 290–292) in 2003, Lieberman and his colleague used functional magnetic resonance imaging (fMRI) to scan the brains of participants as they played a computer game called “cyberball.” In cyberball, participants think that they’re playing an onscreen version of catch with two other people who are using computers linked to their own. For a while the two other people throw the ball regularly to the participant’s onscreen character, but after a while they stop and begin to throw the ball only to each other.
> In reality, the other people don’t exist and the “game” is simply an automatic computer program, but the participant doesn’t know this and feels the sting of social rejection. Using fMRI, the researchers found that this social rejection activated an area of the brain that also lights up in response to physical pain—the anterior cingulate cortex.
> However, they also found that people who had relatively less activity in that area—and who reported feeling relatively less distress—had more activity in the right ventral lateral prefrontal cortex, an area of the brain associated with verbalizing thoughts and language production. So, according to Lieberman, this suggests that putting feelings into words may activate this part of the prefrontal cortex, which may in turn suppress the area of the brain that produces emotional distress.
> Using fMRI, the researchers found that when the participants labeled the faces’ emotions using words, they showed less activity in the amygdala—an area of the brain associated with emotional distress. At the same time, they showed more activity in the right ventral lateral prefrontal cortex—the same language-related area that showed up in the cyberball study. So, again, this suggests that verbalizing an emotion may activate the right ventral lateral prefrontal cortex, which then suppresses the areas of the brain that produce emotional pain.
> “[In talk therapy] we tend to focus primarily on content and enhanced understandings and changed understandings,” said Lieberman. “But it’s not entirely irrelevant that they all involve putting feelings into words.”"
fMRI based research is fascinating and has a bright future, but it's future is not here yet. The science of neuro-psychology is not yet at the point that it can identify widely accepted meaning from activity by location in the brain. There is a body of research that associate emotional expression and memory with the amygdala. There is also a body of research that relates the prefrontal cortex with modulating emotion with verbal behavior. Presumably, the process of putting emotions into words requires the individual to arrive at an interpretation of the emotion, the stimulus and thoughts about both. However to conclude a temporal, even causal, relationship between these two areas that results in "suppressing" emotion requires huge leaps in logic.
The final statement in the excerpt I find incredibly presumptuous. Certainly, true believers in cognitive-behavior therapy are focused almost exclusively on enhancing and changing understandings. But every therapist is acutely aware of how many clients seem able to "understand" why they need to change their behavior, but seem somehow incapable of doing so. Over the years, the concept of resistance has been used as a blanket explanation for this phenomena. Somehow, the client either consciously or unconsciously doesn't want to change. It's never been explained why a client would go through the expense, emotional pain and embarrassment of seeing a therapist and then decide they don't want to change. Of course at least some clients do indeed go to a therapist and then withdraw when they discover what is necessary. But that would hardly explain all such occurrences, and probably not even a majority.
Most therapists I know presume emotion plays a major part in the client's inability to make changes they know they need to make. The father of attachment theory, [John Bowlby](http://www.amazon.com/gp/redirect.html?ie=UTF8&location=http%3A%2F%2Fwww.amazon.com%2FTransforming-Power-Affect-Accelerated-Change%2Fdp%2F0465095674%3Fie%3DUTF8%26s%3Dbooks%26qid%3D1182714431%26sr%3D8-1&tag=daretodream06-20&linkCode=ur2&camp=1789&creative=9325) posits the client's emotional isolation limits awareness and reinforces his inability to make changes.
> "The disastrous experience of aloneness - unwilled, unwanted, dreaded aloneness (as opposed to sought-after, willed, restorative aloneness) - and the pathology-creating anxiety that accompanies it numb the mind and necessarily render huge regions of the self inaccessible. ... fear fostering aloneness arises in response to the unresponsiveness and unavailability of the other when the self is in need. "
[Diane Fosha](http://www.amazon.com/gp/redirect.html?ie=UTF8&location=http%3A%2F%2Fwww.amazon.com%2FTransforming-Power-Affect-Accelerated-Change%2Fdp%2F0465095674%3Fie%3DUTF8%26s%3Dbooks%26qid%3D1182714431%26sr%3D8-1&tag=daretodream06-20&linkCode=ur2&camp=1789&creative=9325)![](http://www.assoc-amazon.com/e/ir?t=daretodream06-20&amp;l=ur2&amp;o=1) describes how the relationship with the therapist and the emotional exchange, creates a healing attachment that enables change.
> "Through affective resonance, sharing, and empathy, the therapist's affective response to the patient's experience serves to amplify the patient's affective experience. ...unlocking a patient's awareness of and grief about the suffering he has undergone. [..] Being right next to the person so intimately, so tenderly, so closely, with so much feeling, melts resistance. The patient finds himself wanting to speak, wanting to share, finding and naturally coming upon essential parts of the self previously hidden from the world as well as from himself."
Bowlby and Fosha's concepts of therapeutic change seems to be consistent with Leiberman's research. Applying the rich theory of attachment, one can extract significantly more meaning from research. Verbalizing emotion may change the emotional memory of traumatic events. The memory of the emotion and so perhaps the next experience of that emotion may well be changed rather than "suppressed". Re-experiencing the event through expression may allow for integration into cognitive schemas about similar events. These speculations would be much more difficult to research than Lieberman's idea, the concept is grounded in widely accepted theory and therefore immediately relevant to practitioners.