---
title: >-
  The Existential Experience of the Trauma Should Be the Focus of Treatment in
  PTSD
id: 324
categories:
  - Blogging on Peer Reviewed Research
  - Emotional Intelligence
  - Post Traumatic Stress Disorder
  - Shame
  - Surviving Traumatic Stress
date: 2012-01-11 14:39:42
tags:
---

How we integrate or make sense of our experiences have a lot to do with how they affect us. That's just common sense. However, the drive within psychology towards a research and [evidence based practice](http://en.wikipedia.org/wiki/Evidence-based_practice "Evidence-based practice") standards has led to a move away from seeking the consensus of practicing professionals in the field on the formation of theory. A theory informed practice has been the standard for many years. Experts construct a theory based on their professional knowledge, including research. The theory is then tested based on the defined concrete references of the theory, called operational definitions. This is a very common approach to theory construction. For example, testing the theory that the planets orbit the sun, one mathematically works out where each planet should be at some set time in the future based on the theory. When they are found there, that provides one study supporting the [criterian validity](http://www.socialresearchmethods.net/kb/constval.php) of the theory that the the planets orbit the sun. 

<span style="float: left; padding: 5px;">[![ResearchBlogging.org](http://www.researchblogging.org/public/citation_icons/rb2_large_gray.png)](http://www.researchblogging.org)</span>
The problem is that psychological constructs are notoriously defined differently by different researchers, and there is little consensus on a grand theory that attempts to explain human behavior. Instead there are a number of theories that have been developed that accounts for behavior based on the thoughts that occur before the behaviors. Research has shown that behavior can change when thoughts about that behavior change. This has been replicated many times. Cognitive behavior therapy is the model in the psychology that enjoys the largest following. But this theory does not explain all or even most behavior, nor does in fit with some of the more common beliefs and assumptions about human behavior.

If changing one's thinking were all that was necessary to change behavior, then more people would be successful with [New Year's resolutions](http://en.wikipedia.org/wiki/New_Year%27s_resolution "New Year"). Most people will tell you of their dismal success breaking old habits in the New Year. Throughout 2007, [one study](http://www.quirkology.com/UK/Experiment_resolution.shtml) tracked over 3000 people attempting to achieve a range of resolutions, including losing weight, visiting the gym, quitting smoking, and drinking less. At the start of the study, 52% of participants were confident of success. One year later, only 12% actually achieved their goal.

Another problem with [Cognitive Behavior Theory (CBT)](http://blog.davemsw.com/archives/2006/07/cognitive_behavior_therapy_the.php) is that it assumes that emotions are just an another form of behavior caused by thoughts. In some cases this may be true. In generally healthy people, emotional issues may well respond to changes in thoughts. But it's clear that [Post Traumatic Stress Disorder](http://www.webmd.com/anxiety-panic/guide/post-traumatic-stress-disorder "Post Traumatic Stress Disorder") (PTSD) is largely an emotional disorder, where manifestations have incomplete connections to thoughts. CBT is not the treatment of choice. Some form of exposure therapy is widely used to essentially break the pattern of emotionally driven habitual behavior or extinguish the conditioned emotional responses to thoughts, feelings and external stimulation associated with the trauma. If you experience that memory and it's emotions in a safe setting and recognize that your fears were not realized, then the memory is changed with the addition of this new information. This sort of change is incremental. Such learning may need to be repeated several times the intensity of the emotion subsides to acceptable levels.

Other clinicians see a more profound version of PTSD in combat veterans.

> Throughout history, warriors have been confronted with moral and ethical  challenges and modern unconventional and guerilla wars amplify these challenges. Potentially morally injurious events, such as perpetrating, failing to prevent, or bearing witness to acts that transgress deeply held moral beliefs and expectations may be deleterious in the long-term,  emotionally, <div class="zemanta-img mt-image-right zemanta-action-dragged" style="margin-top: 1em; margin-right: 1em; margin-bottom: 1em; margin-left: 1em; display: block; float: right; width: 160px; ">[![KHOST, AFGHANISTAN - JANUARY 07:  Military med...](http://cache.daylife.com/imageserve/06gK5uXfAK03B/150x100.jpg)](http://www.daylife.com/image/06gK5uXfAK03B?utm_source=zemanta&amp;utm_medium=p&amp;utm_content=06gK5uXfAK03B&amp;utm_campaign=z1)
> 
> Image by [Getty Images](http://www.daylife.com/source/Getty_Images) via [@daylife](http://www.daylife.com/)
> </div>psychologically, behaviorally, spiritually, and socially (what we label as _moral injury_). Although there has been some research on the consequences of unnecessary acts of violence in war zones, the lasting impact of morally injurious experience in war remains  chiefly unaddressed. To stimulate a critical examination of moral injury, we review the available literature, define terms, and offer a working conceptual framework and a set of intervention strategies designed to repair moral injury. (Litz et al., 2009)
> Georgetown University ethics professor Nancy Sherman heard stories of moral trauma when she interviewed veterans of Iraq, Afghanistan, Vietnam and World War II for her 2010 book, The Untold War. "It might be where you felt you should have been able to do more for your buddies, but you couldn't, or because you simply survived," she says. 
> 
> "Regret," she writes, "doesn't begin to capture what the soldiers I talked with feel. It doesn't capture the despair or depth of the feeling -- the awful weight of self-indictment and the need to make moral repair in order to be allowed back into the community in which he feels he has somehow jeopardized his standing." (Silver, 2011)This is not a new idea, but rather repackaging of a well documented feature of all trauma, and not just trauma related to combat. Themes of shame and guilt pervade the PTSD literature, often referred to as complicating factors.

> Studies suggest that those who interpret a traumatic experience as intensely negative are more at risk for posttraumatic distress and disorder than those who view the event as less traumatic. Specifically, a woman's reaction at the time of her victimization is likely to be an important predictor of her later psychological state. (Briere &amp; Jordan, 2004)
Certainly conceiving of a victim's behavior during a traumatic event as transgressions of deeply held moral beliefs and expectations would qualify as a particularly negative interpretation of the event and thus predict a more difficult recovery. She is also more likely to develop a [shame-based](http://blog.davemsw.com/archives/2010/07/gazing_in_the_looking_glass_without_selfpunishment.php) view of herself based on the conclusion that she has demonstrated a moral defect reflected in her behavior. In my clinical work, I've seen this phenomena in traumatization caused by crime victimization, particularly rape, in natural disasters, such as hurricaine Katrina and the [Northridge earthquake](http://en.wikipedia.org/wiki/1994_Northridge_earthquake "1994 Northridge earthquake") in Oakland, Ca, as well as combat trauma from Iraq, Afghanistan and Vietnam.  The complicating factor of shameful beliefs about personal responsibility when others are injured is a prominent feature in people struggling with a difficult recovery.

This new conceptualization of _moral injury_ may come in a useful form, one that is easily understood by the client and destigmatizing in the sense that a "mental health" problem is consistent with cultural norms. In addition, the authors further the theory of PTSD and its notorious resistance to treatment. The shame of a _moral injury_ leads the sufferer to withdraw from social contact even with close confidants, under the assumption that if she doesn't hide their shameful behavior, others will know and find her disgusting and worthy of rejection. This prevents the natural healing process of sharing and reexperiencing the trauma with the support of a loved one. The expression of love and acceptance despite their shameful behavior becomes part of the emotional memory and gradually attenuates the shame as well as the intrusive memories, nightmares and flashbacks.  The authors note that self esteem has been found to mediate between belief that the world is just and in the willingness to self forgive Therefore, self-esteem may be an protective factor from moral injury. The authors also note that PTSD as well as _moral injury_ involve healthy feelings. The affliction of a moral injury is in part a believe that the sufferer is not worthy of self-forgiveness. (Litz et al., 2009)

Litz et al., (2009) outlines a model they call a "modified CBT" approach. They describe eight components: 1\. A strong working alliance. 2\. Educating about the concept of _moral injury_ and preparing a plan for change. 3\. a "hot-cognitive" exposure based processing or emotion focused self-disclosure. 4\. A thorough examination of the implications of this experience on the sufferers concept of self and other cognitive schemas. 5\. An imaginal dialogue with a benevolent moral authority (such as a grandparent or pastor) about the target behavior and implications for the future. 6\. Fostering self-forgiveness and reconnection to the community. 7\. An assessment of goals and values moving forward.

I've found it particularly effective to treat PTSD complicated by shame in a group setting, where the many components often become a natural process of the group's cohesion and mutual support. When other group members who suffer from post trauma symptoms share their story of how they believed they had personal responsibility that resulted in another's injury, it's much easier for the sufferer to see other's over reactions and offer support and validation. This helps them recognize their own exaggerated self-blame and begin the process of self-forgiveness, a kind of "opposite action" treatment.

References

*   Briere, J. (2002). Treating adult survivors of severe childhood abuse and neglect: Further development of an integrative model. In L. Berliner, J. Briere, C. T. Hendrix, T. Reid, &amp; C. Jenny (Eds.), The APSAC handbook on child maltreatment; 2nd Edition., Briere (2002) (pp. 1-26). Newbury Park; CA: Sage Publications.
*   Briere, J., &amp; Jordan, C. E. (2004). Violence against women: Outcome complexity and implications. Journal Of Interpersonal Violence, 199(11), 1252-1276\.*   <span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Clinical+Psychology+Review&amp;rft_id=info%3Adoi%2F10.1016%2Fj.cpr.2009.07.003&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Moral+injury+and+moral+repair+in+war+veterans%3A+A+preliminary+model+and+intervention+strategy&amp;rft.issn=02727358&amp;rft.date=2009&amp;rft.volume=29&amp;rft.issue=8&amp;rft.spage=695&amp;rft.epage=706&amp;rft.artnum=http%3A%2F%2Flinkinghub.elsevier.com%2Fretrieve%2Fpii%2FS0272735809000920&amp;rft.au=Litz%2C+B.&amp;rft.au=Stein%2C+N.&amp;rft.au=Delaney%2C+E.&amp;rft.au=Lebowitz%2C+L.&amp;rft.au=Nash%2C+W.&amp;rft.au=Silva%2C+C.&amp;rft.au=Maguen%2C+S.&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Litz, B., Stein, N., Delaney, E., Lebowitz, L., Nash, W., Silva, C., &amp; Maguen, S. (2009). Moral injury and moral repair in war veterans: A preliminary model and intervention strategy <span style="font-style: italic;">Clinical Psychology Review, 29</span> (8), 695-706 DOI: [10.1016/j.cpr.2009.07.003](http://dx.doi.org/10.1016/j.cpr.2009.07.003)</span>
*   Silver, D. (2011, September 3). Beyond PTSD: Soldiers Have Injured Souls. Truthout. Retrieved from http://www.truth-out.org/beyond-ptsd-soldiers-have-injured-souls/1315066215
<div class="zemanta-pixie" style="margin-top:10px;height:15px">![](http://img.zemanta.com/pixy.gif?x-id=9319a7a4-802e-423d-9cee-bddc178ed38a)</div>