---
title: >-
  The Essence of Human Experience: What is Normal? Emotional Intelligence for
  Personal Growth, Part V
tags:
  - emotional intelligence
  - habit
  - human experience
  - legal boundaries
  - married man
  - personal growth
  - religious institutions
  - single moment
  - thinking about things
  - thoughts and feelings
id: 310
categories:
  - Blogging on Peer Reviewed Research
  - Child Development
  - Emotional Intelligence
  - Parenting
  - Relationships
  - Research In Brain Function
date: 2010-04-09 12:49:27
---

_This is the fifth in a series of articles on Emotional Intelligence for Personal Growth._
Probably all of us have asked our self from time to time if our thoughts, feelings, or behavior at any single moment is "normal". Actually, there are different answers for each one of these.
[Normal behavior](http://en.wikipedia.org/wiki/Normality_%28behavior%29 "Normality (behavior)") is, like it or not, defined by our legal, community (family, neighborhood, [social group](http://en.wikipedia.org/wiki/Social_group "Social group")) and religious institutions. The law is enforced by our local police, and sanctioned by our courts. Religious values might be said to be collectively defined by our church going population and it's leadership. If we are observed behaving outside of legal boundaries, we may find ourselves in a court room facing a judge. If we stretch our community or religious values, we might be ostracized, and separated from the kind of support we have been reliant on through our life.
Our internal life, our thoughts and feelings, that which goes on within ourselves may be our last real privacy. And that is indeed fortunate. Our internal creativity is uncomfortably broad. We are capable of thinking and feeling most anything from time to time. Under provocation, we are capable of thinking about things we would never do. Angry enough, we may think of assault, even murder. Seeing a pretty woman, a married man might think about cheating on his wife, but never act on that thought. Shocked about a death in the family, our first thoughts may be directed at the inconvenience of disrupting out usual routine and our feelings might be closer to annoyed. Our thoughts and our feelings often contradict each other. In a real sense, we live a dual existence.
Duality
Our body speaks to us through our feelings. Messages are typically fast, automatic, effortless, associative, not available to reflection, and often emotionally charged. Messages are also governed by habit and are therefore difficult to control or modify without time and significant effort. Curiously, since the messages do not require conscious awareness, they do not cause or suffer much interference when combined with other tasks.
Our thoughts, however, are relatively slower, serial, effortful, more likely to be consciously monitored and deliberately controlled. Compared to feelings, thoughts are relatively flexible and thus change readily and can be directed by conscious or habitual rules. Because thoughts are effortful, they tend to disrupt each other. Thus monitoring mental operations for quality interferes with monitoring overt behavior. People who are occupied by a demanding mental activity are more likely to respond to another task by blurting out whatever comes to mind.
<span style="float: left; padding: 5px;">[![ResearchBlogging.org](http://www.researchblogging.org/public/citation_icons/rb2_large_gray.png)](http://www.researchblogging.org)</span>
Intuitive judgments combine the function of feelings and thoughts. The perceptual system and intuitive about perceptions generate impressions of the attributes of objects. These impressions are neither voluntary nor verbally explicit. Judgments are always intentional and explicit even when they are not overtly expressed. Thus, thinking is involved in all judgments and can be reflected upon, whether they originate in impressions or in deliberate reasoning. Monitoring of intuitive judgments is normally quite lax and allows many to be expressed, including some that are erroneous (Kahneman, 2003).
We perceive reality by these two interactive, parallel processing systems.
> "The rational system , a relative newcomer on the evolutionary scene, is a deliberative, verbally mediated, primarily conscious analytical system that functions by a person's understanding of conventionally established rules of logic and evidence. The experiential system, which is considered to be shared by all higher order organisms (although more complex in humans), has a much longer evolutionary history, operates in an automatic, holistic, associationistic manner, is intimately associated with the experience of affect, represents events in the form of concrete exemplars and schemas inductively derived from emotionally significant past experiences, and is able to generalize and to construct relatively complex models for organizing experience and directing behavior by the use of prototypes, metaphors, scripts, and narratives. Although the experimental system is generally adaptive in natural situations, it is often maladaptive in unnatural situations that cannot be solved on the basis of generalizations from past experience but require logical analysis and an understanding of abstract relations.
> 
> [B]ehavior is guided by the joint operation of the two systems, with their relative influence being determined by the nature of the situation and the degree of emotional involvement. Certain situations (e.g., solving mathematical problems) are readily identified as requiring analytical processing, whereas others (e.g., interpersonal behaviors) are more likely to be responded to in an automatic, experientially determined manner. Holding such situational features constant, the greater the emotional involvement, the greater the shift in the balance of influence from the rational to the experiential system (Denes-Raj &amp; Epstein, 1994). "
One might ask, why are there two systems? Many of us have at times wished that our emotions could quiet themselves or even go away. Our culture has a bias towards logic and is suspicious of our emotional side. To quote [Ayn Rand](http://en.wikipedia.org/wiki/Ayn_Rand "Ayn Rand"):
> "A philosophic system is an integrated view of existence. As a human being, you have no choice about the fact that you need a philosophy. Your only choice is whether you define your philosophy by a conscious, rational, disciplined process of thought and scrupulously logical deliberation - or let your subconscious accumulate a junk heap of unwarranted conclusions, false generalizations, undefined contradictions, undigested slogans, unidentified wishes, doubts and fears, thrown together by chance, but integrated by your subconscious into a kind of mongrel philosophy and fused into a single, solid weight: self-doubt, like a bail and chain in the place where your mind's wings should have grown..."
Not matter how much we wish we could be logical and rational, there is a burgeoning literature that says otherwise. Our decisions are evident in our brain activity long before we are consciously aware (For example, see Libet et al., 1983 and Dennett, 2003). We have a dual system of [decision making](http://en.wikipedia.org/wiki/Decision_making "Decision making") because it works. Think about it. How often to we make decisions where we have all the information we need to be absolutely sure that our [logical deduction](http://en.wikipedia.org/wiki/Logic "Logic") is correct? I would venture to say that being sure is limited to only our most simple and concrete decisions. Most every other decision involves weighing facts, impressions, intuitions, and feelings and making as best a decision as possible.
<div class="zemanta-img mt-image-right" style="margin-top: 1em; margin-right: 1em; margin-bottom: 1em; margin-left: 1em; display: block; float: right; width: 249px; ">[![CGI image of rod piercing Phineas Gage](http://upload.wikimedia.org/wikipedia/commons/b/b0/Phineas_Gage_CGI.jpg)](http://commons.wikipedia.org/wiki/Image:Phineas_Gage_CGI.jpg)

Image via [Wikipedia](http://commons.wikipedia.org/wiki/Image:Phineas_Gage_CGI.jpg)
</div>
[Phineas Gage](http://en.wikipedia.org/wiki/Phineas_Gage "Phineas Gage") is perhaps the most famous neurology patient of all time. After a gruesome injury in which he was impaled through his skull by a metal rod and then miraculously recovered, poor Phineas retained all the logic he ever had, but was completely unable to make a decision. He was also left without any awareness or expression of emotion (Demasio, 1994). The very act of making a decision is an emotional process. We choose our decisions among competing alternatives based not only the evidence, but what feels best to us, our "gut level" reaction.
The story behind this dual system is most evident in normal social development.
The Attachment Relationship
John Bowlby (1969/1982) is credited as the founder of [Attachment Theory](http://en.wikipedia.org/wiki/Attachment_theory "Attachment theory"), based on his observations that the quality of a child's social development was largely determined by the quality of the child's relationship with her caregiver. Mary Ainsworth and Mary Main began the research that would ultimately follow children over their first 20 years of development demonstrating Bowlby's concepts to be true and elaborating that theory to account for how, as a child and adult, how freely and effectively she can think, feel, remember, and act (Ainsworth et al., 1978, Main et al., 1985 &amp; Fonagy et al., 2002). Fonagy went on to find that a parents style of attachment before birth predicts their one year old child's attachment style. The parent's ability to mentalize strongly predicted their child's subsequent security. Perhaps most importantly, the the strength of the adult's ability to mentalize enables her to strengthen their attachment style.
> "Attachment is not an end in it's self; rather it exists in order to produce a representational system that has evolved, we may presume, to aid human survival. The quality of our attachment enables us to understand, interpret, and predict the behavior of others as well as our own behavior. It is the cornerstone of social intelligence (Wallin, 2007)."
It is through attachment experiences as a child that she develops rudimentary affect regulation. In the loving care of her caregiver, the child senses that connection to others can be a source of relief, comfort, and pleasure. The child ultimately learns that she -- in expressing its full range of bodily and emotional experiences and needs -- is good, loved, accepted, and competent.
One of the more interesting parts of the process is the role of imitation, mirroring and empathy. There is growing evidence that the same brain areas involved in the execution and observation of motor actions also become active when people listen to sentences that describe the performance of human actions using hands, mouths, or legs, or when people imagine performing an action without actual movement. It would appear that the processes of motor control, mirroring, and mental simulation (or imagination) rely on shared neural circuits (van Gog et al., 2009). While a mother interacts with her child, they interact in a largely non-verbal body-based union. This process of attunement builds within her child a largely emotional communication system that becomes the foundation of intimacy in all future relationships.
> "[T]hrough a kind of "social biofeedback," the child comes to associate the initially involuntary expressions of her emotions with the responses of the caregiver. That is, the infant comes to "know" that her affects are responsible for evoking the caregiver's affect-mirroring responses. Thus, in the most desirable scenario, the infant is learning a number of very useful things: (1) that expressing her feelings can bring about positive outcomes--which generates positive feelings about the self and others; (2) that she can have impact on others--which generates a dawning sense of agency or self-initiative; and (3) gradually, that particular affects elicit particular reactions-- which helps her begin to differentiate and eventually name her feelings (Fonagy et al., 2002) A relationship of secure attachment can thus be seen as a school in which we learn to effectively regulate affects not only in early childhood but throughout our lives (Wallin, 2007)"
Through the secure attachment experience, the child learns to reflect on her feelings and thoughts. Her sense of security, flexibility, and internal freedom becomes very much enhanced. Secure attachment embodies a quality of attunement and contingent responsiveness between mother and infant that is close but imperfect. By the very process of attunement, distraction and reconnection, the child learns that her own internal states are sharable and, at the same time, distinct from those of her caregiver, she recognizes herself and her caregiver as a separate persons, rather than objects. From the loss and regaining of attuned connection emerges from the discovery that the other, and the relationship itself, can survive anger and conflict, and learn to balance the needs for self-definition and relatedness. The parent must reflect on emotion, her's and her child's, so as to make sense and inform her responses. She effectively regulates her own emotions while modeling how the child can regulate hers. Raw feelings become namable and integrated in interaction with her. The child creates representations of her emotion, then the parent names those emotions through her body, feelings and finally words.
Much learning is acquired in non-verbal form while the child acquires language skills. Some learning may be stored unconsciously, for example, when thought, felt, or spoken, this information could threaten vital relationships, especially formative and traumatic experiences. The center of verbal memory, the Broca's area of brain doesn't come on-line until 18-36 months, remains a secondary process until after a child enters school and continues to mature well into adolescence. Traumatic experiences cause overwhelming emotions, which effectively shuts down Broca's area, limiting verbal learning. So much emotional learning happens after childhood during highly emotional experiences.
Explicit memory, the verbal memory of Broca's area of the brain, can be consciously retrieved and reflected upon. This memory can be readily turned into words, it is symbolic, and it's content is information and images.  Implicit memory is present from birth and includes reflexes that are not learned as well as emotional learning acquired in childhood or traumatic learning at any age. It is largely nonverbal, nonsymbolic, unconscious in the sense that it can't be reflected upon. The content includes emotional reactions, patterns of behavior, and skills related to knowing how to do things without thinking. These memories cannot be recalled, but they can be recognized, for example, like deja vois. From implicit memory comes our personal style, implicit relational knowing (gut-level knowledge) and some relational expectations. Perhaps most significant to this article, implicit memory includes the internal working model of attachment. Our attachment style is often enacted without awareness, especially in non-verbal communication.
Ultimately, through our early intimate relationships, we make sense of ourselves and others in terms of a "coherent autobiographical and biographical narrative", a personal story (Wallin, 2007).
Adult Experience - Duality Integrated
We have a built in need to be around people. Our social nature has been built in for thousands of generations with genetic and biochemical support. We feel pleasure just being around people with whom we feel safe. Our social group also influences our behaviors and values. We are reminded by our knowledge of social expectations within the
Continue reading [The Essence of Human Experience: What is Normal? Emotional Intelligence for Personal Growth, Part V.](http://www.blog.davemsw.com/archives/2010/04/the_essence_of_the_human_experience_what_is_normal.php#more)

<fieldset class="zemanta-related"><legend class="zemanta-related-title">Related articles by Zemanta</legend>

*   [Emotional Intelligence for Personal Growth - Part I](http://www.blog.davemsw.com/archives/2010/01/emotional_intelligence_for_personal_growth.php) (blog.davemsw.com)
*   [Mindfulness - Emotional Intelligence for Personal Growth Part II](http://www.blog.davemsw.com/archives/2010/01/mindfulness_emotional_intelligence_for_personal_gr.php) (blog.davemsw.com)
*   [Self-Awareness - Emotional Intelligence For Personal Growth Part III](http://www.blog.davemsw.com/archives/2010/01/selfawareness_emotional_intelligence_for_personal.php) (blog.davemsw.com)
*   [Self-Knowledge - Emotional Intelligence For Personal Growth Part IV](http://www.blog.davemsw.com/archives/2010/03/selfknowledge_emotional_intelligence_for_personal.php) (blog.davemsw.com)</fieldset>

<!--more-->
group and by feedback from other members. A knowledge of our own values and expectations is required to retain an identity separate from the group. Otherwise we could find ourselves at risk of fully adopting those of the social group. There are many lessons in history that speak to the dangers of losing ourselves in a social group because such groups tend to set their own interests and agenda independent from and often contrary to their members.
The human brain is a highly complex organ. It responds to many priorities, some of them may not align with our values. It is common, even expected, that we will think and feel in ways that are very different from our values or actions. That doesn't suggest anything has changed or that we are at risk for acting out of character. In fact, I believe that if we don't think or feel outside of our own values at times, we may be disconnected from our internal states. Being out of touch with thoughts and feelings leaves us vulnerable to being overwhelmed by unexpected and compelling impulses to act, and because they are liable to be unfamiliar and unexpected, they will be more difficult to assess and suppress.
There are no abnormal thoughts or feelings. Because there are few if any intrinsic brain-based limits, thoughts and feelings do not necessarily reflect at all in our behavior or character. Just because we think of something doesn't mean we are more likely to act on it. If we have a strong feeling, we choose whether or not to act on that feeling. That feeling does not control our actions. Even though we may feel the compelling need to act, we can overcome that impulse. Many of us can think of times when anger, or desire pushed us strongly to act impulsively. We may not recall deciding to give in to our impulse. That is indeed conveniently forgotten fact, for we are ethically and legally responsible for that behavior.
We have reflex-like behaviors evoked by startling events like a loud noise, or a visually perceived incoming object. We duck instantly without thinking. There are many simple reactive behaviors like this. They appear to be defensive in nature and not the sort of complex behavior we might immediately regret, like a cross word, or an assaultive behavior.
While it may be true that people can provoke us, they cannot make us act against our will without extreme coercion. We may not be able to stop a thought or feeling from occurring, but we can always change it. By refocusing our attention on another thought or feeling, our mind shifts. A persistent thought or feeling may reassert itself, but we weaken it's persistence every time we push it aside with another.
Of course, we don't want to deliberately focus our attention on a particularly unhealthy and pleasurable thought for any length of time. That is how we create persistently intrusive thoughts or feelings. The more we allow ourselves to dwell on a thought or feeling, the more it will persist. If a persistent thought or feeling dominates our awareness so much that it interferes with our work, our relationships, and our ability to pay attention and learn, it becomes "abnormal" in that it interferes with our ability to function, our quality of life, and our ability to survive should conditions become extreme.
Every day, we might expect to feel a full range of emotions, many we can name, some we may not. Emotions are the color of our days. We can experience bright and warm sunlight and a dark scary storm all in the same day. This is as it should be. Emotions add significant information to our everyday experience.
Perhaps the most important role emotions provide for us is a means to instantaneously appraise the safety of a situation. This evaluative function operates automatically, often without our conscious awareness(Klauer et al., 2009). It's primary purpose appears to be to enhance survival in the face of environmental and social threats, providing an initial appraisal of the event as worthy of approach or avoidance. This emotionally based appraisal system provides us with the means to respond immediately even to an ambiguous situation, thus buying us some time protect ourselves or to assess the situation consciously for any less obvious threats or benefits.
The emotion of fear protects us. Anger warns us we have been treated disrespectfully. Guilt helps us reassess our values. Sadness helps us review our losses and learn from them. The emotion of disgust may be one of the most important primary motivators for disease avoidance. Rotten food, a dead animal typically stimulates a feeling of revulsion, and/or nausea, and with a strong desire to withdraw (Rozin, Haidt, &amp; McCauley, 2000). All emotion provides a cue cooresponding to the current situation and the motivation to respond.
Social behavior is a joint function of two distinct kinds of cognitive processes: the impulsive and the reasoned. Perceptual input directly triggers impulsive processes based on innate and emotion-based learning and general involve activation of the autonomic (automatic) nervous system steering us toward approach or avoidance behavior (Strack &amp; Deutsch, 2004). Reasoning takes significantly more time and conscious awareness and serves as a check on our impulses. "Aspects of a situation are consciously perceived and categorized, knowledge about the value and potential consequences of different behavioral options is weighted and integrated", a decision is made about what action is considered appropriate and that behavior is initiated (Back et al., 2009).
Emotions serve as a quick appraisal tool that then is checked by our reasoned responses. We are able to direct the emotional motivation based on our reasoned choices.  Emotion regulation and redirection is a key part of our social judgment and behavior (Rottenberg &amp; Gross, 2003).
Emotion regulation sometimes fails, resulting in unintended social outcomes and can lead to interpersonal violence. The available evidence suggests that emotional behavior is not uncontrollable; many such acts are "neither a premeditated action nor an irresistible impulse" (Baumeister, 1997). Effective self-regulation is a key part of successful social behavior (Finkel et al., 2009).
Individuals are normally surprisingly accurate in their ability to interpret verbal and non-verbal cues in communication based on brief samples of expressive behavior. However, social judgment accuracy is quite susceptible to emotional influences. These influences likely play an important role both in the formation of the superficial relationships that constitute the majority of one's daily social encounters and in the maintenance of long-term relationships that provide invaluable social support. Sadness significantly impairs the ability to interpret brief cues to important social constructs. Instead of drawing quick intuitive conclusions from subtle even unconscious cues, careful and diligent conscious review impairs social judgment accuracy (Ambady &amp; Gray, 2002). My clinical experience suggests the problem comes from dismissing our gut-level intuitive assessments and replacing them with more "rational" decisions. Our instinctive reactions and intuitive judgments have been carefully honed for thousands of generations and so are quite accurate at judging a social situation where non-verbal nuance and even deception may be an important consideration.
Some researchers have gone so far as to assert that our decisions are predetermined by brain activity initiating muscular reactions before we become consciously aware of the stimulus in question (Libet et al., 1983). Bandura (2008), the father of social learning theory, asserts unequivocally that we act as agents in our social environment. Although we are neither aware of nor directly control our brain, we exercise second-order control. We intentionally engaging in activities known to be functionally related to our intentions, and thus we direct sub-conscious processes and contribute to the resulting behaviors. Our sensory, motor, and cerebral apparatus are tools we use to accomplish the tasks and goals that give meaning, direction, and satisfaction to our lives.
> "To make their way successfully through a complex world full of challenges and hazards, people have to make sound judgments about their capabilities, anticipate the probable effects of different events and courses of action, size up socio-structural opportunities and constraints and regulate their behavior accordingly. These belief systems are a working model of the world that enables people to achieve desired futures and avoid untoward ones (Bandura 2008, p168).
> 
> [...] The self is the person, not a homunculan overseer that resides in a particular place and does the thinking and acting. Selfhood embodies one's physical and psychosocial makeup; with a personal identity and agentic capabilities operating in concert. Although the brain plays a central role in psychological life, selfhood does not reside solely in the brain, any more than the heart is the sole place where circulation is located. [...] Individuals wrestle with conflicting goals and courses of action. However, given but a single body, the choices finally made and the actions taken at a given time require unity of agency. Successful implementation of a chosen course of action also calls for coherent effort (Bandura 2008, p170). "
Fonagy et al., (2002) called the skill of self-reflection and interpretation "mentalizing". He defines mentalizing as "the process by which we realize that having a mind mediates our experience in the world". "Mentalizing proper" is meta-thought, or thoughts about our thoughts. Mentalizing, according to Fonagy, is the principle means we acquire self-knowledge. Through this skill, we acquire assumptions about our social environment and how we learn from it. Our understanding is always incomplete because we sometimes unconsciously distort our conscious understanding by unconscious processes to evade pain or responsibility. Explicit effort is required to identify mental states underlying behavior in terms of beliefs, feelings, desires. Perhaps most importantly, our own internal states affect our interpretations of others, and feelings, thoughts and observations may be inconsistent. Mental states evolve as we experience and learn from them. Caregivers shape behavior of children, and adults must take responsibility to revise this influence. Try as we might to interpret the subtle cues from another, we cannot know what another knows without being told. And each listener will have a unique reaction to what he hears.
Mindfulness fosters integration of the social--emotional right brain and the interpreting left brain. Feelings can be informed by thought and thought by feelings. With mindfulness, we step beyond mentalizing. By repeatedly becoming aware of awareness, we shift the locus of subjectivity from representations of the self to awareness itself. Mindfulness allows us to make sense of our awareness of feelings and thoughts and offers a calm spacious meta-awareness or centerness, that makes us less vulnerable to confusing our internal experience with who we are. Self becomes a continuous flow of aware experiences (Wallin, 2007).
"Our reified images of self serve only to constrain the limits of potentials for understanding and growth" (Wallin, 2007). By immersing ourselves in the moment, we become a fully integrated and achieve maximum social ability to learn and act in a complex environment.
Continued [here](http://www.blog.davemsw.com/archives/2010/05/the_two_darts_of_suffering_pain_is_inevitable_suff.php).
References
<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Journal+of+personality+and+social+psychology&amp;rft_id=info%3Apmid%2F12374446&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=On+being+sad+and+mistaken%3A+mood+effects+on+the+accuracy+of+thin-slice+judgments.&amp;rft.issn=0022-3514&amp;rft.date=2002&amp;rft.volume=83&amp;rft.issue=4&amp;rft.spage=947&amp;rft.epage=61&amp;rft.artnum=&amp;rft.au=Ambady+N&amp;rft.au=Gray+HM&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Ambady N, &amp; Gray HM (2002). On being sad and mistaken: mood effects on the accuracy of thin-slice judgments. <span style="font-style: italic;">Journal of personality and social psychology, 83</span> (4), 947-61 PMID: [12374446](http://www.ncbi.nlm.nih.gov/pubmed/12374446)</span>

Ainsworth et al., (1978) cited in Wallin, D. J. (2007). Attachment in Psychotherapy. New York: The Guildford Press.

<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Journal+of+personality+and+social+psychology&amp;rft_id=info%3Apmid%2F19686006&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Predicting+actual+behavior+from+the+explicit+and+implicit+self-concept+of+personality.&amp;rft.issn=0022-3514&amp;rft.date=2009&amp;rft.volume=97&amp;rft.issue=3&amp;rft.spage=533&amp;rft.epage=48&amp;rft.artnum=&amp;rft.au=Back+MD&amp;rft.au=Schmukle+SC&amp;rft.au=Egloff+B&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Back MD, Schmukle SC, &amp; Egloff B (2009). Predicting actual behavior from the explicit and implicit self-concept of personality. <span style="font-style: italic;">Journal of personality and social psychology, 97</span> (3), 533-48 PMID: [19686006](http://www.ncbi.nlm.nih.gov/pubmed/19686006)</span>

<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Perspectives+on+Psychological+Science&amp;rft_id=info%3Adoi%2F10.1111%2Fj.1745-6916.2006.00011.x&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Toward+a+Psychology+of+Human+Agency&amp;rft.issn=1745-6916&amp;rft.date=2006&amp;rft.volume=1&amp;rft.issue=2&amp;rft.spage=164&amp;rft.epage=180&amp;rft.artnum=http%3A%2F%2Fpps.sagepub.com%2Flookup%2Fdoi%2F10.1111%2Fj.1745-6916.2006.00011.x&amp;rft.au=Bandura%2C+A.&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Bandura, A. (2006). Toward a Psychology of Human Agency <span style="font-style: italic;">Perspectives on Psychological Science, 1</span> (2), 164-180 DOI: [10.1111/j.1745-6916.2006.00011.x](http://dx.doi.org/10.1111/j.1745-6916.2006.00011.x)</span>

Baumeister, 1997 cited in Finkel, E. J., DeWall, C. N., Slotter, E. B., Oaten, M., &amp; Foshee, V. A. (2009). Self-Regulatory Failure and Intimate Partner Violence Perpetration. Journal of Personality and Social Psychology, 97(3), 483-499.

Bowlby, John (1969/1982) cited in Wallin, D. J. (2007). Attachment in Psychotherapy. New York: The Guildford Press.

<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Journal+of+personality+and+social+psychology&amp;rft_id=info%3Apmid%2F8014830&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Conflict+between+intuitive+and+rational+processing%3A+when+people+behave+against+their+better+judgment.&amp;rft.issn=0022-3514&amp;rft.date=1994&amp;rft.volume=66&amp;rft.issue=5&amp;rft.spage=819&amp;rft.epage=29&amp;rft.artnum=&amp;rft.au=Denes-Raj+V&amp;rft.au=Epstein+S&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Denes-Raj V, &amp; Epstein S (1994). Conflict between intuitive and rational processing: when people behave against their better judgment. <span style="font-style: italic;">Journal of Personality and Social Psychology, 66</span> (5), 819-29 PMID: [8014830](http://www.ncbi.nlm.nih.gov/pubmed/8014830)</span> 

Demasio, A. (1994). Emotion, Reason and the Human Brain. New York: Avon Books.
<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Annals+of+the+New+York+Academy+of+Sciences&amp;rft_id=info%3Adoi%2F10.1196%2Fannals.1279.003&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=The+Self+as+a+Responding-and+Responsible-Artifact&amp;rft.issn=00778923&amp;rft.date=2003&amp;rft.volume=1001&amp;rft.issue=1&amp;rft.spage=39&amp;rft.epage=50&amp;rft.artnum=http%3A%2F%2Fblackwell-synergy.com%2Fdoi%2Fabs%2F10.1196%2Fannals.1279.003&amp;rft.au=DENNETT%2C+D.&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Dennett, D. (2003). The Self as a Responding-and Responsible-Artifact <span style="font-style: italic;">Annals of the New York Academy of Sciences, 1001</span> (1), 39-50 DOI: [10.1196/annals.1279.003](http://dx.doi.org/10.1196/annals.1279.003)</span>
<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Journal+of+personality+and+social+psychology&amp;rft_id=info%3Apmid%2F19686003&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Self-regulatory+failure+and+intimate+partner+violence+perpetration.&amp;rft.issn=0022-3514&amp;rft.date=2009&amp;rft.volume=97&amp;rft.issue=3&amp;rft.spage=483&amp;rft.epage=99&amp;rft.artnum=&amp;rft.au=Finkel+EJ&amp;rft.au=DeWall+CN&amp;rft.au=Slotter+EB&amp;rft.au=Oaten+M&amp;rft.au=Foshee+VA&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Finkel EJ, DeWall CN, Slotter EB, Oaten M, &amp; Foshee VA (2009). Self-regulatory failure and intimate partner violence perpetration. <span style="font-style: italic;">Journal of Personality and Social Psychology, 97</span> (3), 483-99 PMID: [19686003](http://www.ncbi.nlm.nih.gov/pubmed/19686003)</span> 

Fonagy et al., (2002), cited in Wallin, D. J. (2007). Attachment in Psychotherapy. New York: The Guildford Press.
<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=The+American+psychologist&amp;rft_id=info%3Apmid%2F14584987&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=A+perspective+on+judgment+and+choice%3A+mapping+bounded+rationality.&amp;rft.issn=0003-066X&amp;rft.date=2003&amp;rft.volume=58&amp;rft.issue=9&amp;rft.spage=697&amp;rft.epage=720&amp;rft.artnum=&amp;rft.au=Kahneman+D&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Kahneman D (2003). A perspective on judgment and choice: mapping bounded rationality. <span style="font-style: italic;">The American Psychologist, 58</span> (9), 697-720 PMID: [14584987](http://www.ncbi.nlm.nih.gov/pubmed/14584987)</span>
<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Journal+of+personality+and+social+psychology&amp;rft_id=info%3Apmid%2F19159132&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Contrast+effects+in+spontaneous+evaluations%3A+a+psychophysical+account.&amp;rft.issn=0022-3514&amp;rft.date=2009&amp;rft.volume=96&amp;rft.issue=2&amp;rft.spage=265&amp;rft.epage=87&amp;rft.artnum=&amp;rft.au=Klauer+KC&amp;rft.au=Teige-Mocigemba+S&amp;rft.au=Spruyt+A&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Klauer KC, Teige-Mocigemba S, &amp; Spruyt A (2009). Contrast effects in spontaneous evaluations: a psychophysical account. <span style="font-style: italic;">Journal of Personality and Social Psychology, 96</span> (2), 265-87 PMID: [19159132](http://www.ncbi.nlm.nih.gov/pubmed/19159132)</span>

<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Brain+%3A+a+journal+of+neurology&amp;rft_id=info%3Apmid%2F6640273&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Time+of+conscious+intention+to+act+in+relation+to+onset+of+cerebral+activity+%28readiness-potential%29.+The+unconscious+initiation+of+a+freely+voluntary+act.&amp;rft.issn=0006-8950&amp;rft.date=1983&amp;rft.volume=106+%28Pt+3%29&amp;rft.issue=&amp;rft.spage=623&amp;rft.epage=42&amp;rft.artnum=&amp;rft.au=Libet+B&amp;rft.au=Gleason+CA&amp;rft.au=Wright+EW&amp;rft.au=Pearl+DK&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Libet B, Gleason CA, Wright EW, &amp; Pearl DK (1983). Time of conscious intention to act in relation to onset of cerebral activity (readiness-potential). The unconscious initiation of a freely voluntary act. <span style="font-style: italic;">Brain : a journal of neurology, 106 (Pt 3)</span>, 623-42 PMID: [6640273](http://www.ncbi.nlm.nih.gov/pubmed/6640273)</span>

Main et al., (1985) cited in Wallin, D. J. (2007). Attachment in Psychotherapy. New York: The Guildford Press.
<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Psychological+bulletin&amp;rft_id=info%3Apmid%2F19254082&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=Disgust+as+a+disease-avoidance+mechanism.&amp;rft.issn=0033-2909&amp;rft.date=2009&amp;rft.volume=135&amp;rft.issue=2&amp;rft.spage=303&amp;rft.epage=21&amp;rft.artnum=&amp;rft.au=Oaten+M&amp;rft.au=Stevenson+RJ&amp;rft.au=Case+TI&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Oaten M, Stevenson RJ, &amp; Case TI (2009). Disgust as a disease-avoidance mechanism. <span style="font-style: italic;">Psychological Bulletin, 135</span> (2), 303-21 PMID: [19254082](http://www.ncbi.nlm.nih.gov/pubmed/19254082)</span>

<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Clinical+Psychology%3A+Science+and+Practice&amp;rft_id=info%3Adoi%2F10.1093%2Fclipsy%2Fbpg012&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=When+Emotion+Goes+Wrong%3A+Realizing+the+Promise+of+Affective+Science&amp;rft.issn=14682850&amp;rft.date=2003&amp;rft.volume=10&amp;rft.issue=2&amp;rft.spage=227&amp;rft.epage=232&amp;rft.artnum=http%3A%2F%2Fdoi.wiley.com%2F10.1093%2Fclipsy%2Fbpg012&amp;rft.au=Rottenberg%2C+J.&amp;rfe_dat=bpr3.included=1;bpr3.tags=Psychology">Rottenberg, J. (2003). When Emotion Goes Wrong: Realizing the Promise of Affective Science <span style="font-style: italic;">Clinical Psychology: Science and Practice, 10</span> (2), 227-232 DOI: [10.1093/clipsy/bpg012](http://dx.doi.org/10.1093/clipsy/bpg012)</span>

Rozin, Haidt, &amp; McCauley, (2000) cited in Oaten, M., Stevenson, R. J., &amp; Case, T. I. (2009). Disgust as a Disease-Avoidance Mechanism. Psychological Bulletin, 135(2), 303-321.

Strack &amp; Deutsch, (2004) cited in Back, M. D., Schmukle, S. C., &amp; Egloff, B. (2009). Predicting Actual Behavior From the Explicit and Implicit Self-Concept of Personality. Journal of Personality and Social Psychology, 97(3), 533-548

<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal&amp;rft.jtitle=Educational+Psychology+Review&amp;rft_id=info%3Adoi%2F10.1007%2Fs10648-008-9094-3&amp;rfr_id=info%3Asid%2Fresearchblogging.org&amp;rft.atitle=The+Mirror+Neuron+System+and+Observational+Learning%3A+Implications+for+the+Effectiveness+of+Dynamic+Visualizations&amp;rft.issn=1040-726X&amp;rft.date=2008&amp;rft.volume=21&amp;rft.issue=1&amp;rft.spage=21&amp;rft.epage=30&amp;rft.artnum=http%3A%2F%2Fwww.springerlink.com%2Findex%2F10.1007%2Fs10648-008-9094-3&amp;rft.au=Gog%2C+T.&amp;rft.au=Paas%2C+F.&amp;rft.au=Marcus%2C+N.&amp;rft.au=Ayres%2C+P.&amp;rft.au=Sweller%2C+J.&amp;rfe_dat=bpr3.included=1;bpr3.tags=">Gog, T., Paas, F., Marcus, N., Ayres, P., &amp; Sweller, J. (2008). The Mirror Neuron System and Observational Learning: Implications for the Effectiveness of Dynamic Visualizations <span style="font-style: italic;">Educational Psychology Review, 21</span> (1), 21-30 DOI: [10.1007/s10648-008-9094-3](http://dx.doi.org/10.1007/s10648-008-9094-3)</span>

Wallin, D. J. (2007). Attachment in Psychotherapy. New York: The Guildford Press.
<fieldset class="zemanta-related"><legend class="zemanta-related-title">Related articles by Zemanta</legend>

*   [Emotional Intelligence for Personal Growth - Part I](http://www.blog.davemsw.com/archives/2010/01/emotional_intelligence_for_personal_growth.php) (blog.davemsw.com)
*   [Mindfulness - Emotional Intelligence for Personal Growth Part II](http://www.blog.davemsw.com/archives/2010/01/mindfulness_emotional_intelligence_for_personal_gr.php) (blog.davemsw.com)
*   [Self-Awareness - Emotional Intelligence For Personal Growth Part III](http://www.blog.davemsw.com/archives/2010/01/selfawareness_emotional_intelligence_for_personal.php) (blog.davemsw.com)
*   [Self-Knowledge - Emotional Intelligence For Personal Growth Part IV](http://www.blog.davemsw.com/archives/2010/03/selfknowledge_emotional_intelligence_for_personal.php) (blog.davemsw.com)
*   [Self-Awareness - Emotional Intelligence For Personal Growth Part III](http://www.blog.davemsw.com/archives/2010/01/selfawareness_emotional_intelligence_for_personal.php) (blog.davemsw.com)</fieldset>
<div style="margin-top: 10px; height: 15px;" class="zemanta-pixie">[![Reblog this post [with Zemanta]](http://img.zemanta.com/reblog_c.png?x-id=0e075b13-c5bb-4186-bae4-622c2a1a743f)](http://reblog.zemanta.com/zemified/0e075b13-c5bb-4186-bae4-622c2a1a743f/ "Reblog this post [with Zemanta]")<span class="zem-script more-related pretty-attribution"><script type="text/javascript" src="http://static.zemanta.com/readside/loader.js" defer="defer"></script></span></div>